@@ -3,18 +3,23 @@ eval 'require Digest::MD5';
 
 @prereq = qw(IO Net::FTP Compress::Zlib Digest::MD5 MIME::Base64
 	URI HTML::Parser LWP);
-@useful = (qw(Storable Sys::Syslog Net::Daemon RPC::PlServer
+@useful = (qw(Storable Time::Timezone Sys::Syslog Net::Daemon
+        RPC::PlServer
         DBI DBD::XBase DB_File File::Tools Mail::Tools
 	SQL::Statement Text::CSV_XS DBD::CSV FreezeThaw IniConf
         Data::Dumper GD MLDBM Convert::BER Net::LDAP XML::Parser
         Net::DNS Net::Whois Net::Country Tie::Cache Tie::DBI
-	Filter::Util::Call Template));
+	Filter::Util::Call Template XML::Simple Date::Language));
 
 if ($ARGV[0] eq 'NOPREREQ') {
 	@modules = @useful;
 	shift @ARGV;
 } else {
 	@modules = (@prereq, @useful);
+        if ($] < 5.6) {
+            print "Try: perl pre-install NOPREREQ\nif CPAN tries helplessly to download Perl 5.6.0 and install it\07\n";
+            sleep 4;
+        }
 }
 
 unshift(@INC, $ARGV[0]) if (@ARGV);
